@@ -1,11 +1,3 @@
-/* Ai Carumba */
-
-#include "puredb_p.h"
-#include "puredb_read.h"
-#include "puredb_write.h"
-
-/* I wish there was an easier way to get version constants ;) */
-
 #ifdef VERSION
 #define  realVERSION VERSION
 #undef VERSION
@@ -21,3 +13,12 @@
 #endif
 #define the_puredb_PACKAGE_STRING PACKAGE_STRING
 
+#include <sys/types.h>
+#ifndef off_t
+#define off_t long
+#endif
+#ifndef size_t
+#define size_t unsigned
+#endif
+
+
