@@ -7,31 +7,40 @@ Tie::PureDB - Perl extension for pure-db
   use Tie::PureDB;
   my $file = 'foo.db';
   {
-      my %db;
-      tie %db, 'Tie::PureDB::Write', "$file.index", "$file.data", $file
-          or die "Couldn't create database $@";
+      tie my %db, 'Tie::PureDB::Write', "$file.index", "$file.data", $file
+          or die "Couldn't create database ($!)";
+
       $db{createtime} = scalar gmtime;
       $db{$_} = rand($_) for 1..100;
+
       untie %db;
 
       tie %db, 'Tie::PureDB::Read', $file
-          or die "Couldn't read database $@";
+          or die "Couldn't read database ($!)";
+
       print "This database was created on $db{createtime}\n";
       print " 1 => $db{1}\n 6 => $db{6}\n\n";
+
       untie %db;
   }
   {
       my $db = Tie::PureDB::Write->new( "$file.index", "$file.data", $file )
-          or die "Couldn't create database $@";
+          or die "Couldn't create database ($!)";
+
       $db->puredbw_add( createtime => scalar gmtime );
       $db->add( $_ => rand($_)) for 1..100;
+
       undef $db;
 
       $db = Tie::PureDB::Read->($file)
-          or die "Couldn't read database $@";
-      print "This database was created on ", $db->read( $db->puredb_find('createtime') ), \n";
-      print " 1 => ", $db->FETCH(1), "\n";
-      print " 1 => ", $db->FETCH(9), "\n";
+          or die "Couldn't read database ($!)";
+
+      print "This database was created on ",
+          $db->read( $db->puredb_find('createtime') ), \n";
+
+      print " 1 => ", $db->FETCH(1) || "EEEK!($!)", "\n";
+      print " 1 => ", $db->FETCH(9) || "EEEK!($!)", "\n";
+
       undef $db;
   }
 
@@ -55,7 +64,7 @@ use DynaLoader();
 use vars qw[ @ISA $VERSION ];
 @ISA = qw( DynaLoader );
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 bootstrap Tie::PureDB $VERSION;
 
@@ -69,12 +78,13 @@ This is the interface to libpuredb_write.
 
 If you use the tie interface, you can only use it to store values
 (C<$db{foo}=1;> aka C<(tied %db)-E<gt>STORE(foo =E<gt> 1);> ).
+It is highly reccomended that you use the tie interface.
 
-If you use the function interface, you'll wanna use
+If you use the function interface, you'll wanna use the following functions.
 
-=head2 new
+=head2 puredbw_open
 
-Also known as open, or puredbw_open.
+Also known as C<open>, or C<new>.
 It takes 3 arguments: file_index, file_data, file_final.
 
 On success, returns a Tie::PureDB::Write object.
@@ -100,7 +110,7 @@ sub new {
 
 =head2 add
 
-Also known as open, or puredbw_add.
+Also known as C<open>, or C<puredbw_add>.
 It takes 2 arguments: key,value.
 
 On success, returns a true value.
@@ -114,7 +124,7 @@ sub puredbw_add {
     return xs_puredbw_add($$self, $key, $value);
 }
 
-=head2 CAVEATS (undefined functions)
+=head2 CAVEATS(undefined functions)
 
 Don't try to use the following functions, they are not defined
 (for example: C<keys %db>.  See L<perltie|perltie> for more info details.).
@@ -153,6 +163,8 @@ sub DESTROY {
 
 
 package Tie::PureDB::Read;
+use Carp qw[ carp croak ];
+use strict;
 
 =head1 Tie::PureDB::Read
 
@@ -160,12 +172,13 @@ This is the interface to libpuredb_read.
 
 If you use the tie interface, you can only use it to read values
 (C<print $db{foo};> aka C<print (tied %db)-E<gt>FETCH('foo');> ).
+It is highly reccomended that you use the tie interface.
 
-If you use the function interface, you'll wanna use
+If you use the function interface, you'll wanna use the following functions.
 
-=head2 new
+=head2 puredb_open
 
-Also known as open, or puredb_open.
+Also known as C<new>, or C<open>.
 It takes 1 arguments: file_final.
 
 On success, returns a Tie::PureDB::Read object.
@@ -176,6 +189,12 @@ On failure, returns nothing while setting $!.
 { no strict 'refs'; *open = *puredb_open = *new; }
 sub new {
     my $package = shift;
+
+    croak "Usage error : 1 argument of length greater than 0 expected"
+        unless @_
+            and defined $_[0]
+            and length $_[0];
+
     my $it = xs_new(@_);
     return bless \$it, $package if defined $it;
 }
@@ -183,7 +202,7 @@ sub new {
 
 =head2 getsize
 
-Also known as puredb_getsize.
+Also known as C<puredb_getsize>.
 Takes 0 arguments.
 Returns the size of the database in bytes
 (same number as C<-s $file>).
@@ -199,14 +218,14 @@ sub puredb_getsize {
 
 =head2 find
 
-Also known as puredb_find.
+Also known as C<puredb_find>.
 Takes 1 argument (the key to find),
 On success, returns offset,length.
 On failure, returns nothing while setting $!.
 
 =cut
 
-{ no strict 'refs'; *find = *puredb_find; }
+{ no strict 'refs'; *find = *EXISTS = *puredb_find; }
 sub puredb_find {
     my $self = shift;
 
@@ -215,11 +234,16 @@ sub puredb_find {
 
 =head2 read
 
-Also known as puredb_read.
+Also known as C<puredb_read>.
 Takes 2 arguments (offset,length).
 On success, returns the value.
 On failure, returns nothing while setting $!.
 
+B<**WARNING> --
+It is highly discouraged that you use C<read> with invalid offsets.
+Always use those returned by C<find>,
+or simply use C<FETCH> or the tie interface.
+
 =cut
 
 { no strict 'refs'; *read = *puredb_read; }
@@ -247,11 +271,6 @@ sub FETCH  {
     }
 }
 
-sub EXISTS {
-    my($self,$key) = @_;
-    return xs_puredb_find($$self, $key);
-}
-
 sub TIEHASH { goto &new;  }
 
 sub DESTROY {
@@ -291,14 +310,34 @@ globally shared data, and as such, they are "thread-safe".
 If you aren't aware of the I<Gotcha>,
 read about it before even attempting to use this module ;)
 
-L<perltie|perltie>L<The untie Gotcha|perltie/The untie Gotcha>. 
+L<The untie Gotcha|perltie/The untie Gotcha> in L<perltie|perltie>.
+
+
+=head1 Memoize
+
+You could use Memoize with this module.
+All you have to do is add the following lines to your program:
+
+    use Tie::PureDB;
+    BEGIN{
+        package Tie::PureDB::Read;
+        use Memoize();
+        Memoize::memoize('puredb_read','puredb_find','FETCH');
+        no strict 'refs';
+        *read = *puredb_read;
+        *find = *puredb_find;
+        *EXISTS = *puredb_find;
+        package main;
+    }
+    ## ... rest of your code follows
+
 
 =head1 AUTHOR
 
 D. H. E<lt>PodMaster@cpan.orgE<gt>
 who is very thankful to I<tye and B<the perlmonks>>,
-as well as Tim Jenness and Simon Cozens, authors of
-Extending and Embedding Perl ( http://www.manning.com/jenness/ ).
+as well as Tim Jenness and Simon Cozens
+(authors of Extending and Embedding Perl -- http://www.manning.com/jenness/ ).
 
 =head1 SEE ALSO
 
@@ -311,4 +350,4 @@ L<BerkeleyDB>.
 
 =cut
 
-## damn link targets podchecker
\ No newline at end of file
+## damn link targets podchecker
